@@ -1,6 +1,6 @@
 /* Parse command line arguments for Bison.
 
-   Copyright (C) 1984, 1986, 1989, 1992, 2000-2015, 2018-2020 Free
+   Copyright (C) 1984, 1986, 1989, 1992, 2000-2015, 2018-2021 Free
    Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #include <config.h>
 #include "getargs.h"
@@ -38,8 +38,9 @@
 #include "output.h"
 #include "uniqstr.h"
 
-bool defines_flag = false;
+bool header_flag = false;
 bool graph_flag = false;
+bool html_flag = false;
 bool xml_flag = false;
 bool no_lines_flag = false;
 bool token_table_flag = false;
@@ -221,7 +222,7 @@ static const argmatch_report_arg argmatch_report_args[] =
   { "none",            report_none },
   { "states",          report_states },
   { "itemsets",        report_states | report_itemsets },
-  { "lookaheads",      report_states | report_lookahead_tokens },
+  { "lookaheads",      report_states | report_lookaheads },
   { "solved",          report_states | report_solved_conflicts },
   { "counterexamples", report_cex },
   { "cex",             report_cex },
@@ -422,11 +423,9 @@ Tuning the Parser:\n\
 "), stdout);
       putc ('\n', stdout);
 
-      /* Keep -d and --defines separate so that ../build-aux/cross-options.pl
-       * won't assume that -d also takes an argument.  */
       fputs (_("\
 Output Files:\n\
-      --defines[=FILE]          also produce a header file\n\
+  -H, --header=[FILE]           also produce a header file\n\
   -d                            likewise but cannot specify FILE (for POSIX Yacc)\n\
   -r, --report=THINGS           also produce details on the automaton\n\
       --report-file=FILE        write report to FILE\n\
@@ -434,6 +433,7 @@ Output Files:\n\
   -b, --file-prefix=PREFIX      specify a PREFIX for output files\n\
   -o, --output=FILE             leave output to FILE\n\
   -g, --graph[=FILE]            also output a graph of the automaton\n\
+      --html[=FILE]             also output an HTML report of the automaton\n\
   -x, --xml[=FILE]              also output an XML report of the automaton\n\
   -M, --file-prefix-map=OLD=NEW replace prefix OLD with NEW when writing file paths\n\
                                 in output files\n\
@@ -446,7 +446,7 @@ Output Files:\n\
       printf (_("Report bugs to <%s>.\n"), PACKAGE_BUGREPORT);
       printf (_("%s home page: <%s>.\n"), PACKAGE_NAME, PACKAGE_URL);
       fputs (_("General help using GNU software: "
-               "<http://www.gnu.org/gethelp/>.\n"),
+               "<https://www.gnu.org/gethelp/>.\n"),
              stdout);
 
 #if (defined __GLIBC__ && __GLIBC__ >= 2) && !defined __UCLIBC__
@@ -455,13 +455,12 @@ Output Files:\n\
          man page.  */
       const char *lc_messages = setlocale (LC_MESSAGES, NULL);
       if (lc_messages && !STREQ (lc_messages, "en_"))
-        /* TRANSLATORS: Replace LANG_CODE in this URL with your language
-           code <http://translationproject.org/team/LANG_CODE.html> to
-           form one of the URLs at http://translationproject.org/team/.
+        /* TRANSLATORS: Replace LANG_CODE in this URL with your language code to
+           form one of the URLs at https://translationproject.org/team/.
            Otherwise, replace the entire URL with your translation team's
            email address.  */
         fputs (_("Report translation bugs to "
-                 "<http://translationproject.org/team/>.\n"), stdout);
+                 "<https://translationproject.org/team/>.\n"), stdout);
 #endif
       fputs (_("For complete documentation, run: info bison.\n"), stdout);
     }
@@ -479,7 +478,7 @@ version (void)
 {
   /* Some efforts were made to ease the translators' task, please
      continue.  */
-  printf (_("bison (GNU Bison) %s"), VERSION);
+  printf ("bison (GNU Bison) %s", VERSION);
   putc ('\n', stdout);
   fputs (_("Written by Robert Corbett and Richard Stallman.\n"), stdout);
   putc ('\n', stdout);
@@ -545,6 +544,7 @@ language_argmatch (char const *arg, int prio, location loc)
 static char const short_options[] =
   "D:"
   "F:"
+  "H::"
   "L:"
   "S:"
   "T::"
@@ -573,6 +573,7 @@ enum
 {
   COLOR_OPTION = CHAR_MAX + 1,
   FIXED_OUTPUT_FILES_OPTION,
+  HTML_OPTION,
   LOCATIONS_OPTION,
   PRINT_DATADIR_OPTION,
   PRINT_LOCALEDIR_OPTION,
@@ -609,6 +610,7 @@ static struct option const long_options[] =
   { "yacc",           no_argument,         0, 'y' },
 
   /* Output Files. */
+  { "header",          optional_argument,   0,   'H' },
   { "defines",         optional_argument,   0,   'd' },
   { "report",          required_argument,   0,   'r' },
   { "report-file",     required_argument,   0,   REPORT_FILE_OPTION },
@@ -616,6 +618,7 @@ static struct option const long_options[] =
   { "file-prefix",     required_argument,   0,   'b' },
   { "output",          required_argument,   0,   'o' },
   { "graph",           optional_argument,   0,   'g' },
+  { "html",            optional_argument,   0,   HTML_OPTION },
   { "xml",             optional_argument,   0,   'x' },
   { "file-prefix-map", required_argument,   0,   'M' },
 
@@ -719,6 +722,16 @@ getargs (int argc, char *argv[])
         }
         break;
 
+      case 'H':
+      case 'd':
+        header_flag = true;
+        if (optarg)
+          {
+            free (spec_header_file);
+            spec_header_file = xstrdup (optarg);
+          }
+        break;
+
       case 'L':
         language_argmatch (optarg, command_line_prio, loc);
         break;
@@ -763,16 +776,6 @@ getargs (int argc, char *argv[])
         spec_file_prefix = optarg;
         break;
 
-      case 'd':
-        /* Here, the -d and --defines options are differentiated.  */
-        defines_flag = true;
-        if (optarg)
-          {
-            free (spec_header_file);
-            spec_header_file = xstrdup (optarg);
-          }
-        break;
-
       case 'g':
         graph_flag = true;
         if (optarg)
@@ -839,6 +842,16 @@ getargs (int argc, char *argv[])
         /* Handled in getargs_colors. */
         break;
 
+      case HTML_OPTION:
+        html_flag = true;
+        xml_flag = true;
+        if (optarg)
+          {
+            free (spec_html_file);
+            spec_html_file = xstrdup (optarg);
+          }
+        break;
+
       case FIXED_OUTPUT_FILES_OPTION:
         complain (&loc, Wdeprecated,
                   _("deprecated option: %s, use %s"),
